@@ -23,7 +23,7 @@ class Storage(driver.Base):
         print "==========================>jss_bucket:"+config.jss_bucket
         print "==========================>jss_domain:"+config.jss_domain
         
-        self._jss = JssClient(self._access_key, self._secret_key, self._domain, "80")
+        self._jss = JssClient(self._access_key, self._secret_key, self._domain, '80')
         
     def _init_path(self, path=None):
         if path:
@@ -37,13 +37,6 @@ class Storage(driver.Base):
         
         return object_instance.generate_url("GET")
 
-    def get_json(self, path):
-        try:
-            return json.loads(self.get_unicode(path))
-        except Exception as e:
-            print e
-            return []
-
     @lru.get
     def get_content(self, path):
         path = self._init_path(path)
@@ -62,13 +55,14 @@ class Storage(driver.Base):
         path = self._init_path(path)
         try:
             object_instance = self._jss.bucket(self._bucket).object(path)
-            object_instance.upload_flow(None, content)
+            object_instance.upload_flow(None, None, content)
         except Exception as e:
             print e
             raise e
         return path
 
     def stream_write(self, path, fp):
+        print "stream_write path:"+path
         path = self._init_path(path)
         part_size = 5 * 1024 * 1024
         if self.buffer_size < part_size:
@@ -82,6 +76,7 @@ class Storage(driver.Base):
 
     @lru.remove
     def remove(self, path):
+        print "remove path:"+path
         path = self._init_path(path)
 
         try:
